unit MainUnit;

interface

uses
  WinTypes, WinProcs, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, Buttons, ExtCtrls, StdCtrls, RTDesign;

type
  TMainForm = class(TForm)
    MainMenu2: TMainMenu;
    File1: TMenuItem;
    Exit1: TMenuItem;
    N2: TMenuItem;
    SaveAs1: TMenuItem;
    Save1: TMenuItem;
    Open1: TMenuItem;
    New1: TMenuItem;
    Close1: TMenuItem;
    ComponentBar: TPanel;
    BNone: TSpeedButton;
    BLabel: TSpeedButton;
    BEdit: TSpeedButton;
    BButton: TSpeedButton;
    BSpeedButton: TSpeedButton;
    OpenFormDialog: TOpenDialog;
    SaveFormDialog: TSaveDialog;
    Toolbar: TPanel;
    NewTB: TSpeedButton;
    OpenTB: TSpeedButton;
    SaveTB: TSpeedButton;
    Edit1: TMenuItem;
    Paste1: TMenuItem;
    Copy1: TMenuItem;
    Cut1: TMenuItem;
    N4: TMenuItem;
    Undo1: TMenuItem;
    CutTB: TSpeedButton;
    CopyTB: TSpeedButton;
    PasteTB: TSpeedButton;
    RTDesigner1: TRTDesigner;
    N1: TMenuItem;
    Aligntogrid1: TMenuItem;
    Sendtoback1: TMenuItem;
    BringtoFront1: TMenuItem;
    N3: TMenuItem;
    Editmode1: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure Open1Click(Sender: TObject);
    procedure Save1Click(Sender: TObject);
    procedure New1Click(Sender: TObject);
    procedure Close1Click(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure Undo1Click(Sender: TObject);
    procedure Copy1Click(Sender: TObject);
    procedure Paste1Click(Sender: TObject);
    procedure Cut1Click(Sender: TObject);
    procedure RTDesigner1UndoChange(Sender: TObject);
    procedure RTDesigner1InsertQuery(Sender: TObject; Control: TControl;
      var aClass: TControlClass);
    procedure Aligntogrid1Click(Sender: TObject);
    procedure RTDesigner1PopulateDesignerMenu(Sender: TObject;
      var Menu: TPopupMenu);
    procedure RTDesigner1AfterInsert(Sender: TObject; Control: TControl);
    procedure Editmode1Click(Sender: TObject);
  private
  public
    Function GetControlClass : TControlClass;
  end;

var
  MainForm: TMainForm;

implementation

uses MDIChld;

{$R *.DFM}

procedure TMainForm.FormCreate(Sender: TObject);
begin
  RegisterClass(TMDIChild);
end;

Function TMainForm.GetControlClass : TControlClass;
Begin
  Result:=nil;
  if BLabel.Down Then Result:=TLabel
  Else if BEdit.Down Then Result:=TEdit
  Else if BButton.Down Then Result:=TButton
  Else if BSpeedButton.Down Then Result:=TSpeedButton;
  BNone.Down:=True;
End;

procedure TMainForm.Open1Click(Sender: TObject);
var aChild : TMDIChild;
begin
  if not OpenFormDialog.Execute Then Exit;
  aChild:=TMDIChild.Create(Application);
  RTDesigner1.BaseControl:=aChild;
  aChild.FileName:=OpenFormDialog.FileName;
  RTDesigner1.LoadBCFromFile(OpenFormDialog.FileName);
end;

procedure TMainForm.Save1Click(Sender: TObject);
var aFileName : String;
begin
  if MDIChildCount=0 Then Exit;
  aFileName:=TMDIChild(ActiveMDIChild).FileName;
  if (Sender=SaveAs1) or (aFileName='') Then Begin
    if not SaveFormDialog.Execute Then Exit;
    aFileName:=SaveFormDialog.FileName;
  End;
  RTDesigner1.SaveBCToFile(aFileName);
  TMDIChild(ActiveMDIChild).FileName:=aFileName;
end;

procedure TMainForm.New1Click(Sender: TObject);
begin
  TMDIChild.Create(Application).Show;
end;

procedure TMainForm.Close1Click(Sender: TObject);
begin
  ActiveMDIChild.Free;
end;

procedure TMainForm.Exit1Click(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.Undo1Click(Sender: TObject);
begin
  RTDesigner1.Undo;
end;

procedure TMainForm.Copy1Click(Sender: TObject);
begin
  RTDesigner1.CopyToClipboard;
end;

procedure TMainForm.Paste1Click(Sender: TObject);
begin
  RTDesigner1.PasteFromClipboard;
end;

procedure TMainForm.Cut1Click(Sender: TObject);
begin
  RTDesigner1.CopyToClipboard;
  RTDesigner1.DeleteSelection;
end;

procedure TMainForm.RTDesigner1UndoChange(Sender: TObject);
begin
  Undo1.Enabled:=RTDesigner1.UndoKind<>ukNone;
  Undo1.Caption:=RTDesigner1.UndoString;
end;

procedure TMainForm.RTDesigner1InsertQuery(Sender: TObject;
  Control: TControl; var aClass: TControlClass);
begin
  aClass:=GetControlClass;
end;

procedure TMainForm.Aligntogrid1Click(Sender: TObject);
begin
  RTDesigner1.AlignToGrid;
end;

procedure TMainForm.RTDesigner1PopulateDesignerMenu(Sender: TObject;
  var Menu: TPopupMenu);
begin
  Menu.Items.Add(NewLine);
  Menu.Items.Add(NewItem('This is only an example', 0, False, True, nil, 0, 'PopupMenuExample1'));
  Menu.Items.Add(NewItem('how to use OnPopulateDesignMenu', 0, False, True, nil, 0, 'PopupMenuExample2'));
end;

procedure TMainForm.RTDesigner1AfterInsert(Sender: TObject;
  Control: TControl);
begin
  if Control is TLabel Then TLabel(Control).Transparent:=True;
end;

procedure TMainForm.Editmode1Click(Sender: TObject);
begin
  RTDesigner1.EditMode:=not RTDesigner1.EditMode;
  EditMode1.Checked:=RTDesigner1.EditMode;
end;

end.
